@@ -71,6 +71,7 @@ void pdl_thread_mismatch_msg(
 );
 void pdl_dump_flags_fixspace(int flags, int nspac, pdl_flags type);
 void pdl_dump_trans_fixspace(pdl_trans *it, int nspac);
+void pdl_dump_anyval(PDL_Anyval v);
 
 #define PDL_CORE_LIST(X) \
   X(SvPDLV, pdl*, ( SV* )) \
@@ -124,7 +125,6 @@ void pdl_dump_trans_fixspace(pdl_trans *it, int nspac);
   X(safe_indterm, PDL_Indx, (PDL_Indx dsz, PDL_Indx at, char *file, int lineno)) \
   X(propagate_badflag, void, (pdl *it, int newval)) \
   X(propagate_badvalue, void, (pdl *it)) \
-  X(changesoon, pdl_error, (pdl *it)) \
   X(changed, pdl_error, (pdl *it, int what, int recursing)) \
   X(get_pdl_badvalue, PDL_Anyval, (pdl *it)) \
   X(get_badvalue, PDL_Anyval, (int datatype)) \
@@ -156,7 +156,7 @@ PDL_CORE_LIST(X)
 #define X(symbol, ctype, ppsym, shortctype, defbval) \
 PDL_Indx pdl_setav_ ## ppsym(ctype * pdata, AV* av, \
 	PDL_Indx* pdims, PDL_Long ndims, int level, ctype undefval, pdl *p);
-PDL_GENERICLIST(X)
+PDL_TYPELIST_ALL(X)
 #undef X
 
 /* Structure to hold pointers core PDL routines so as to be used by many modules */
