@@ -143,17 +143,16 @@ PDL_LIST_FLAGS_PARAMS(X)
   };
   int typeval[] = {
 #define X(sym, ctype, ppsym, shortctype, defbval) sym,
-PDL_GENERICLIST(X)
+PDL_TYPELIST_ALL(X)
 #undef X
     -1
   };
   char *typechar[] = {
 #define X(sym, ctype, ppsym, shortctype, defbval) #sym,
-PDL_GENERICLIST(X)
+PDL_TYPELIST_ALL(X)
 #undef X
     NULL
   };
-  fflush(stdout);
   printf("DUMPTHREAD %p\n",(void*)thread);
   if (thread->transvtable) {
     pdl_transvtable *vtable = thread->transvtable;
@@ -251,7 +250,6 @@ PDL_GENERICLIST(X)
   for (i=0;i<thread->npdls;i++)
     printf("%s%d",(i?" ":""),thread->flags[i]);
   printf(")\n");
-  fflush(stdout);
 }
 
 void pdl_dump_threading_info(
@@ -407,7 +405,6 @@ void pdl_dump_trans_fixspace (pdl_trans *it, int nspac) {
 	pdl_dump_flags_fixspace(it->flags,nspac+3,PDL_FLAGS_TRANS);
 	printf("%s   vtable flags ",spaces);
 	pdl_dump_flags_fixspace(it->vtable->flags,nspac+3,PDL_FLAGS_VTABLE);
-	fflush(stdout);
 	if(it->flags & PDL_ITRANS_ISAFFINE) {
 		if(it->pdls[1]->state & PDL_PARENTDIMSCHANGED) {
 			printf("%s   AFFINE, BUT DIMSCHANGED\n",spaces);
@@ -484,6 +481,20 @@ void pdl_dump (pdl *it) {
 	pdl_dump_fixspace(it,0);
 }
 
+void pdl_dump_anyval(PDL_Anyval v) {
+  if (v.type < PDL_CF) {
+#define X(datatype, ctype, ppsym, shortctype, defbval) \
+    printf("%Lg", (long double)v.value.ppsym);
+    PDL_GENERICSWITCH(PDL_TYPELIST2_REAL, v.type, X, printf("(UNKNOWN PDL_Anyval type=%d)", v.type))
+#undef X
+  } else {
+#define X(datatype, ctype, ppsym, shortctype, defbval) \
+    printf("%Lg%+Lgi", creall((complex long double)v.value.ppsym), cimagl((complex long double)v.value.ppsym));
+    PDL_GENERICSWITCH(PDL_TYPELIST2_COMPLEX, v.type, X, printf("(UNKNOWN PDL_Anyval type=%d)", v.type))
+#undef X
+  }
+}
+
 void pdl_error_free(pdl_error e) {
   if (e.needs_free == 1) {
     free((void *)e.message);
